Enum Request
#[non_exhaustive]pub enum Request<'a> {
Destroy,
SetToplevelTag {
toplevel: XdgToplevel,
tag: String,
},
SetToplevelDescription {
toplevel: XdgToplevel,
description: String,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
destroy toplevel tag object
Destroy this toplevel tag manager object. This request has no other effects.
This is a destructor, once sent this object cannot be used any longer.
SetToplevelTag
set tag
Set a tag for a toplevel. The tag may be shown to the user in UI, so it’s preferable for it to be human readable, but it must be suitable for configuration files and should not be translated. Suitable tags would for example be “main window”, “settings”, “e-mail composer” or similar.
The tag does not need to be unique across applications, and the client may set the same tag for multiple windows, for example if the user has opened the same UI twice. How the potentially resulting conflicts are handled is compositor policy.
The client should set the tag as part of the initial commit on the associated toplevel, but it may set it at any time afterwards as well, for example if the purpose of the toplevel changes.
SetToplevelDescription
set description
Set a description for a toplevel. This description may be shown to the user in UI or read by a screen reader for accessibility purposes, and should be translated. It is recommended to make the description the translation of the tag.
The client should set the description as part of the initial commit on the associated toplevel, but it may set it at any time afterwards as well, for example if the purpose of the toplevel changes.
Implementations